==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/CellKeyDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { PrimaryKeyValueDescriptionMetadata } from "./PrimaryKeyValueDescriptionMetadata";
import { CellKeyDescription } from "./CellKeyDescription";
/**
 * @hidden
 */
export let CellKeyDescriptionMetadata = /*@__PURE__*/ (() => {
    class CellKeyDescriptionMetadata extends Base {
        static b(a) {
            if (CellKeyDescriptionMetadata.a == null) {
                CellKeyDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                CellKeyDescriptionMetadata.c(CellKeyDescriptionMetadata.a);
            }
            if (a.k(CellKeyDescriptionMetadata.a)) {
                return;
            }
            a.ab(CellKeyDescriptionMetadata.a);
            PrimaryKeyValueDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__marshalByValue", "Boolean");
            a.item("PrimaryKey", "ExportedType:PrimaryKeyValue");
            a.item("RowItem", "Unknown");
            a.item("ColumnUniqueKey", "String");
        }
        static d(a) {
            CellKeyDescriptionMetadata.b(a);
            a.ad("CellKey", () => new CellKeyDescription());
            a.ac("CellKey", CellKeyDescriptionMetadata.a);
        }
    }
    CellKeyDescriptionMetadata.$t = markType(CellKeyDescriptionMetadata, 'CellKeyDescriptionMetadata');
    CellKeyDescriptionMetadata.a = null;
    return CellKeyDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/CellKeyDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { PrimaryKeyValueDescriptionMetadata } from "./PrimaryKeyValueDescriptionMetadata";
import { CellKeyDescription } from "./CellKeyDescription";
/**
 * @hidden
 */
export let CellKeyDescriptionMetadata = /*@__PURE__*/ (() => {
    class CellKeyDescriptionMetadata extends Base {
        static b(a) {
            if (CellKeyDescriptionMetadata.a == null) {
                CellKeyDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                CellKeyDescriptionMetadata.c(CellKeyDescriptionMetadata.a);
            }
            if (a.k(CellKeyDescriptionMetadata.a)) {
                return;
            }
            a.ac(CellKeyDescriptionMetadata.a);
            PrimaryKeyValueDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__marshalByValue", "Boolean");
            a.item("PrimaryKey", "ExportedType:PrimaryKeyValue");
            a.item("RowItem", "Unknown");
            a.item("ColumnUniqueKey", "String");
        }
        static d(a) {
            CellKeyDescriptionMetadata.b(a);
            a.ae("CellKey", () => new CellKeyDescription());
            a.ad("CellKey", CellKeyDescriptionMetadata.a);
        }
    }
    CellKeyDescriptionMetadata.$t = markType(CellKeyDescriptionMetadata, 'CellKeyDescriptionMetadata');
    CellKeyDescriptionMetadata.a = null;
    return CellKeyDescriptionMetadata;
})();
